==> testops-api-1.0.1.tar.gz: testops-api-1.0.1/docs/OrganizationResource.md <==
# OrganizationResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] 
**name** | **str** |  | [optional] 
**role** | **str** |  | [optional] 
**org_feature_flag** | [**OrganizationFeatureFlagResource**](OrganizationFeatureFlagResource.md) |  | [optional] 
**quota_kse** | **int** |  | [optional] 
**machine_quota_kse** | **int** |  | [optional] 
**quota_engine** | **int** |  | [optional] 
**machine_quota_engine** | **int** |  | [optional] 
**used_kse** | **int** |  | [optional] 
**used_engine** | **int** |  | [optional] 
**quota_test_ops** | **int** |  | [optional] 
**used_test_ops** | **int** |  | [optional] 
**number_user** | **int** |  | [optional] 
**quota_floating_engine** | **int** |  | [optional] 
**used_floating_engine** | **int** |  | [optional] 
**can_create_offline_kse** | **bool** |  | [optional] 
**can_create_offline_re** | **bool** |  | [optional] 
**subscription_expiry_date_engine** | **datetime** |  | [optional] 
**subscription_expiry_date_kse** | **datetime** |  | [optional] 
**subscription_expiry_date_floating_engine** | **datetime** |  | [optional] 
**subscription_expiry_date_test_ops** | **datetime** |  | [optional] 
**subscribed** | **bool** |  | [optional] 
**kse_paygo** | **bool** |  | [optional] 
**kre_paygo** | **bool** |  | [optional] 
**paygo_quota** | **int** |  | [optional] 
**domain** | **str** |  | [optional] 
**subdomain_url** | **str** |  | [optional] 
**strict_domain** | **bool** |  | [optional] 
**logo_url** | **str** |  | [optional] 
**saml_sso** | **bool** |  | [optional] 
**kre_license** | **bool** |  | [optional] 
**test_ops_package** | **str** |  | [optional] 
**most_recent_project_accessed_at** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> testops-api-1.0.2.tar.gz: testops-api-1.0.2/docs/OrganizationResource.md <==
# OrganizationResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] 
**name** | **str** |  | [optional] 
**role** | **str** |  | [optional] 
**org_feature_flag** | [**OrganizationFeatureFlagResource**](OrganizationFeatureFlagResource.md) |  | [optional] 
**quota_kse** | **int** |  | [optional] 
**machine_quota_kse** | **int** |  | [optional] 
**quota_unlimited_kse** | **int** |  | [optional] 
**quota_engine** | **int** |  | [optional] 
**machine_quota_engine** | **int** |  | [optional] 
**quota_unlimited_engine** | **int** |  | [optional] 
**used_kse** | **int** |  | [optional] 
**used_unlimited_kse** | **int** |  | [optional] 
**used_engine** | **int** |  | [optional] 
**used_unlimited_engine** | **int** |  | [optional] 
**quota_test_ops** | **int** |  | [optional] 
**used_test_ops** | **int** |  | [optional] 
**number_user** | **int** |  | [optional] 
**quota_floating_engine** | **int** |  | [optional] 
**used_floating_engine** | **int** |  | [optional] 
**can_create_offline_kse** | **bool** |  | [optional] 
**can_create_offline_unlimited_kse** | **bool** |  | [optional] 
**can_create_offline_re** | **bool** |  | [optional] 
**can_create_offline_unlimited_engine** | **bool** |  | [optional] 
**subscription_expiry_date_engine** | **datetime** |  | [optional] 
**subscription_expiry_date_unlimited_engine** | **datetime** |  | [optional] 
**subscription_expiry_date_kse** | **datetime** |  | [optional] 
**subscription_expiry_date_unlimited_kse** | **datetime** |  | [optional] 
**subscription_expiry_date_floating_engine** | **datetime** |  | [optional] 
**subscription_expiry_date_test_ops** | **datetime** |  | [optional] 
**subscribed** | **bool** |  | [optional] 
**kse_paygo** | **bool** |  | [optional] 
**kre_paygo** | **bool** |  | [optional] 
**paygo_quota** | **int** |  | [optional] 
**domain** | **str** |  | [optional] 
**subdomain_url** | **str** |  | [optional] 
**strict_domain** | **bool** |  | [optional] 
**logo_url** | **str** |  | [optional] 
**saml_sso** | **bool** |  | [optional] 
**kre_license** | **bool** |  | [optional] 
**most_recent_project_accessed_at** | **datetime** |  | [optional] 
**account_id** | **int** |  | [optional] 
**test_ops_feature** | **str** |  | [optional] 
**platform_feature** | **str** |  | [optional] 
**tier** | **str** |  | [optional] 
**requested_user_verified** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
